# -*- coding: utf-8 -*-
require 'touggsl'
require 'json'
require 'touggsl/request_helpers'
require 'touggsl/models/customer'
class Touggsl::Customer
  include Touggsl::RequestHelper

  attr_accessor :auth

  ##
  # Recebe um Touggsl::Auth
  #
  # Exemplo:
  #
  #   auth = Touggsl::Auth
  #   auth.login("email, "password")
  #   Touggsl::Client.new(auth)
  #
  def initialize(auth)
    @auth = auth
    include_auth_to_requests(@auth)
  end

  ##
  # Cadastra um novo cliente na Superlogica
  #
  # ==== Prams
  # * <tt>id</tt> - ID para identificar o cliente.
  # * <tt>client_name</tt> - Nome do cliente. Ex: Paulo
  # * <tt>nome_fantasia</tt> - Nome fantasia. Ex: Tougg
  # * <tt>dia_vencimento</tt> - Parametro opcional, por padrao eh setado como 0,
  #   isso significa que nao existe "dia de vencimento" para a fatura do cliente. Se voce deseja
  #   configurar algum dia, 5 por exemplo, para o "vencimento"
  def create_new_client(id, client_name, nome_fantasia, dia_vencimento=0)
    response = create_client(id,client_name, nome_fantasia,dia_vencimento)
    json = JSON.parse(response)

    #create a class for response, at the time only return the
    # status
   json["status"]
  end

  ##
  # Contrata um plano para o cliente.
  #
  # ==== Params
  # * <tt>plan_id</tt> - ID do plano cadastrado na Superlogica
  # * <tt>client_id</tt> - ID do cliente que deseja contratar o plano
  # * <tt>contract_id</tt> - ID do contrato. Unico para cada contratacao de plano
  def hiring_plan(plan_id, client_id, contract_id, forma_pagamento)
    response = hiring_plan_for_client(plan_id, client_id, contract_id, forma_pagamento)
    json = JSON.parse(response)

    status = json["status"]
    if status == "206"
      return "Plano ja contratado ou ID do plano informado nao existe."
    else
      json["data"].each do |d|
        return d["data"]["link_boleto"]
      end
    end
  end

  ##
  # Retorna todos os clientes que estão inadimplentes
  #
  def get_all_inadimplentes
    clients = []
    clients_json = JSON.parse(get_clients_inadimplementes)
    clients_json["data"].each do |j|
      name = j["st_nomeref_sac"]
      recebimento = j["recebimento"]
      dias_atraso = recebimento[0]["encargos"][0]["diasatraso"]
      id_client = j["id_sacado_sac"]
      segunda_via = recebimento[0]["link_2via"]
      clients << Customer.new(id_client, name, dias_atraso, segunda_via)
    end
    clients
  end

  ##
  # Retorna true se cliente esta inadimplente, false caso não for.
  #
  # ==== Params
  # * <tt>client_id</tt> - ID do cliente
  #
  def is_inadimplente(client_id)
    client = JSON.parse(checks_if_client_is_inadimplente(client_id))
    client['data'].length > 0 ? true : false
  end

  ##
  # Retorna link de 2 via do boleto para cliente que nao está inadimplente
  #
  # # ==== Params
  # * <tt>client_id</tt> - ID do cliente
  #
  def link_2via_normal_client(client_id)
    link = JSON.parse(get_2via_link_normal_client(client_id))
    link['data'].each do |d|
      return d['link_2via']
    end
  end

  ##
  # Retorna link de 2 via do boleto para cliente inadimplente
  # ==== Params
  # * <tt>client_id</tt> - ID do cliente
  #
  def link_2via(client_id)
    link = JSON.parse(get_2via_link(client_id))
    link['data'].each do |d|
      d['recebimento'].each do |v|
        return v['link_2via']
      end
    end
  end

  ##
  # Retorna todas as cobrancas do cliente, com status pendente por default
  # ==== Params
  # * <tt>client_id</tt> - ID do cliente
  # * <tt>status</tt> - status das cobranças
  #
  def billings(client_id, status = 'pendentes')
    billings = JSON.parse(billings_request(client_id, status))
    return billings['data']
  end

  ##
  # Liquida uma cobrança
  #
  # ==== Params
  # * <tt>pay_id</tt> - ID do pagamento
  # * <tt>value</tt> - valor da cobrança. Padrão é 24.90.
  #
  def pay(pay_id, value = 24.90)
    pay = JSON.parse(pay_request(pay_id, value))
    status = pay['status'].to_i
    unless status == 200
      return "Ocorreu algum erro."
    end
  end

  ##
  # Gerar uma cobranca
  # * <tt>client_id</tt> - ID do cliente
  # * <tt>data_vencimento</tt> - data de vecimento da cobrança
  # * <tt>product_id</tt> - ID do produto/serviço na superlógica
  # * <tt>value</tt> - valor da cobrança
  # * <tt>account_id</tt> -  ID da conta na superlógica
  #
  def new_billing(client_id, data_vencimento, product_id, value, account_id = 1)
    billing = JSON.parse(new_billing_request(client_id, data_vencimento, product_id, value, account_id))
    if billing['status'].to_i == 200
      billing["data"].each do |d|
        return d["data"]["link_2via"]
      end
    else
      billing['data'].each { |d| puts d['msg'] }
    end
  end
end
